==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/fr.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documents",
    "Can't create document" : "Impossible de créer le document",
    "You don't have permission to rename this document" : "Vous n'avez pas les droits suffisants pour renommer ce document",
    "Directory saved successfully." : "Dossier sauvegardé avec succès.",
    "An error occurred while changing directory." : "Une erreur est survenue lors du changement de dossier.",
    "Saved" : "Sauvegardé",
    "Format filter server is down or misconfigured" : "Le serveur de filtre de format est en panne ou mal configuré",
    "Conversion failed. Check log for details." : "La conversion a échoué. Consultez le journal des erreurs pour plus d’informations.",
    "document-styles" : "document-styles",
    "document-content" : "document-content",
    "bold" : "bold",
    "italic" : "italic",
    "solid" : "solid",
    "pt" : "pt",
    "Saving..." : "Enregistrement...",
    "Failed to load documents." : "Échec du chargement des documents.",
    "No documents were found. Upload or create a document to get started!" : "Aucun document n’a été trouvé. Veuillez en créer un nouveau ou en importer un existant afin de commencer !",
    "No connection to server. Trying to reconnect." : "Aucune connexion au serveur. Tentative de reconnexion en cours.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Quitter cette page lorsqu'en mode \"Éditeur\" peut empêcher la sauvegarde des données. Il est recommandé d'utiliser le bouton \"Fermer\".",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Le chargement du document a échoué. Veuillez vérifier s'il peut être ouvert avec un éditeur odt externe. Il se peut également que le document ait été récemment supprimé ou retiré d'un partage.",
    "Save" : "Sauvegarder",
    "Loading documents..." : "Chargement des documents...",
    "'.' is an invalid file name." : "'.' n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Ce nom n'est pas valide : les caractères '\\', '/', '<', '>', ':', '\"', '|', '?' et '*' ne sont pas autorisés.",
    "Align Left" : "Aligner à gauche",
    "Alignment" : "Alignement",
    "Align Right" : "Aligner à droite",
    "Annotate" : "Annoter",
    "Background" : "Arrière-plan",
    "Bold" : "Gras",
    "Bottom" : "Bas de page",
    "Cancel" : "Annuler",
    "Center" : "Centrer",
    "Clone" : "Dupliquer",
    "Clone this Style" : "Dupliquer ce style",
    "Close" : "Fermer",
    "Color" : "Couleur",
    "Create" : "Créer",
    "Decrease Indent" : "Réduire l'indentation",
    "Default Style" : "Style par défaut",
    "Delete" : "Supprimer",
    "Family" : "Famille",
    "Font" : "Police",
    "Font Effects" : "Effets de police",
    "Format" : "Format",
    "Increase Indent" : "Augmenter l'indentation",
    "Insert Image" : "Insérer une image",
    "Invite Members" : "Inviter des membres",
    "Italic" : "Italique",
    "Justified" : "Justifié",
    "Justify" : "Justifier",
    "Left" : "Gauche",
    "Loading" : "Chargement",
    "Members" : "Membres",
    "New Name:" : "Nouveau nom :",
    "OK" : "OK",
    "Open" : "Ouvrir",
    "Options" : "Options",
    "Paragraph..." : "Paragraphe…",
    "Paragraph Styles" : "Styles de paragraphe",
    "Redo" : "Répéter",
    "Right" : "Droite",
    "Size" : "Taille",
    "Spacing" : "Espacement",
    "Strikethrough" : "Barré",
    "Style" : "Style",
    "Text" : "Texte",
    "Top" : "Haut de page",
    "Underline" : "Souligné",
    "Undo" : "Annuler",
    "Unknown Author" : "Auteur inconnu",
    "Edit" : "Éditer",
    "Share" : "Partager",
    "guest" : "invité",
    "MS Word support (requires openOffice/libreOffice)" : "Prise en charge de MS Word (nécessite OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/LibreOffice est installé sur ce serveur. Le chemin vers le binaire est fourni via preview_libreoffice_path dans config.php",
    "External" : "Externe",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/LibreOffice est installé sur un serveur externe faisant fonctionner un serveur de filtre de format",
    "Disabled" : "Désactivé",
    "No MS Word support" : "Pas de prise en charge de MS Word",
    "scheme://domain.tld[:port]" : "scheme://domaine.tld[:port]",
    "Server URL" : "URL du serveur",
    "Apply and test" : "Appliquer et essayer",
    "New document" : "Nouveau document",
    "Upload (max. %s)" : "Téléversement (max. %s)",
    "Upload" : "Téléverser",
    "Save new documents to" : "Enregistrer les nouveaux documents sous",
    "Wrong password. Please retry." : "Mot de passe erroné. Merci de réessayer.",
    "Password" : "Mot de passe",
    "Guest %s" : "Invité %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a partagé ce lien avec vous.",
    "Advanced feature-set" : "Fonctionnalités avancées",
    "(Unstable)" : "(instable)"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/fr.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documents",
    "Can't create document" : "Impossible de créer le document",
    "You don't have permission to rename this document" : "Vous n'avez pas les droits suffisants pour renommer ce document",
    "File does not exist" : "Le fichier n'existe pas",
    "Directory saved successfully." : "Dossier sauvegardé avec succès.",
    "An error occurred while changing directory." : "Une erreur est survenue lors du changement de dossier.",
    "Saved" : "Sauvegardé",
    "Format filter server is down or misconfigured" : "Le serveur de filtre de format est en panne ou mal configuré",
    "Conversion failed. Check log for details." : "La conversion a échoué. Consultez le journal des erreurs pour plus d’informations.",
    "Saving..." : "Enregistrement...",
    "Failed to load documents." : "Échec du chargement des documents.",
    "No documents were found. Upload or create a document to get started!" : "Aucun document n’a été trouvé. Veuillez en créer un nouveau ou en importer un existant afin de commencer !",
    "No connection to server. Trying to reconnect." : "Aucune connexion au serveur. Tentative de reconnexion en cours.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Quitter cette page lorsqu'en mode \"Éditeur\" peut empêcher la sauvegarde des données. Il est recommandé d'utiliser le bouton \"Fermer\".",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Le chargement du document a échoué. Veuillez vérifier s'il peut être ouvert avec un éditeur odt externe. Il se peut également que le document ait été récemment supprimé ou retiré d'un partage.",
    "Save" : "Sauvegarder",
    "Loading documents..." : "Chargement des documents...",
    "'.' is an invalid file name." : "'.' n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Ce nom n'est pas valide : les caractères '\\', '/', '<', '>', ':', '\"', '|', '?' et '*' ne sont pas autorisés.",
    "Align Left" : "Aligner à gauche",
    "Alignment" : "Alignement",
    "Align Right" : "Aligner à droite",
    "Annotate" : "Annoter",
    "Background" : "Arrière-plan",
    "Bold" : "Gras",
    "Bottom" : "Bas de page",
    "Cancel" : "Annuler",
    "Center" : "Centrer",
    "Clone" : "Dupliquer",
    "Clone this Style" : "Dupliquer ce style",
    "Close" : "Fermer",
    "Color" : "Couleur",
    "Create" : "Créer",
    "Decrease Indent" : "Réduire l'indentation",
    "Default Style" : "Style par défaut",
    "Delete" : "Supprimer",
    "Family" : "Famille",
    "Font" : "Police",
    "Font Effects" : "Effets de police",
    "Format" : "Format",
    "Increase Indent" : "Augmenter l'indentation",
    "Insert Image" : "Insérer une image",
    "Invite Members" : "Inviter des membres",
    "Italic" : "Italique",
    "Justified" : "Justifié",
    "Justify" : "Justifier",
    "Left" : "Gauche",
    "Loading" : "Chargement",
    "Members" : "Membres",
    "New Name:" : "Nouveau nom :",
    "OK" : "OK",
    "Open" : "Ouvrir",
    "Options" : "Options",
    "Paragraph..." : "Paragraphe…",
    "Paragraph Styles" : "Styles de paragraphe",
    "Redo" : "Répéter",
    "Right" : "Droite",
    "Size" : "Taille",
    "Spacing" : "Espacement",
    "Strikethrough" : "Barré",
    "Style" : "Style",
    "Text" : "Texte",
    "Top" : "Haut de page",
    "Underline" : "Souligné",
    "Undo" : "Annuler",
    "Unknown Author" : "Auteur inconnu",
    "Shared" : "Partagé",
    "Error" : "Erreur",
    "Error while sharing" : "Erreur lors de la mise en partage",
    "Error while unsharing" : "Erreur lors de l'annulation du partage",
    "Error while changing permissions" : "Erreur lors du changement des permissions",
    "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
    "Shared with you by {owner}" : "Partagé avec vous par {owner}",
    "Share with users or groups …" : "Partager avec des utilisateurs ou groupes...",
    "Share with users, groups or remote users …" : "Partager avec des utilisateurs, groupes, ou utilisateurs distants",
    "Share" : "Partager",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partagez avec des personnes sur d'autres ownClouds en utilisant la syntaxe utilisateur@exemple.com/owncloud",
    "Share link" : "Partage par lien",
    "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
    "Link" : "Lien",
    "Password protect" : "Protéger par un mot de passe",
    "Password" : "Mot de passe",
    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
    "Allow editing" : "Permettre la modification",
    "Email link to person" : "Envoyer le lien par courriel",
    "Send" : "Envoyer",
    "Set expiration date" : "Spécifier une date d'expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Date d'expiration",
    "An error occured. Please try again" : "Une erreur est survenue. Merci de réessayer",
    "Adding user..." : "Ajout de l'utilisateur...",
    "group" : "groupe",
    "remote" : "distant",
    "Resharing is not allowed" : "Le repartage n'est pas autorisé",
    "Shared in {item} with {user}" : "Partagé dans {item} avec {user}",
    "Unshare" : "Ne plus partager",
    "notify by email" : "notifier par courriel",
    "can share" : "peut partager",
    "can edit" : "peut modifier",
    "access control" : "contrôle d'accès",
    "create" : "création",
    "change" : "modification",
    "delete" : "suppression",
    "Password protected" : "Protégé par mot de passe",
    "Error unsetting expiration date" : "Erreur lors de la suppression de la date d'expiration",
    "Error setting expiration date" : "Erreur lors de la spécification de la date d'expiration",
    "Sending ..." : "Envoi…",
    "Email sent" : "E-mail envoyé",
    "Warning" : "Attention",
    "Edit" : "Éditer",
    "guest" : "invité",
    "MS Word support (requires openOffice/libreOffice)" : "Prise en charge de MS Word (nécessite OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/LibreOffice est installé sur ce serveur. Le chemin vers le binaire est fourni via preview_libreoffice_path dans config.php",
    "External" : "Externe",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/LibreOffice est installé sur un serveur externe faisant fonctionner un serveur de filtre de format",
    "Disabled" : "Désactivé",
    "No MS Word support" : "Pas de prise en charge de MS Word",
    "scheme://domain.tld[:port]" : "scheme://domaine.tld[:port]",
    "Server URL" : "URL du serveur",
    "Apply and test" : "Appliquer et essayer",
    "New document" : "Nouveau document",
    "Upload (max. %s)" : "Téléversement (max. %s)",
    "Upload" : "Téléverser",
    "Save new documents to" : "Enregistrer les nouveaux documents sous",
    "Wrong password. Please retry." : "Mot de passe erroné. Merci de réessayer.",
    "Guest %s" : "Invité %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a partagé ce lien avec vous.",
    "Advanced feature-set" : "Fonctionnalités avancées",
    "(Unstable)" : "(instable)"
},
"nplurals=2; plural=(n > 1);");
